jcm_root = getenv('JCMROOT'); % Linux: use: jcm_root = <JCMROOT> -> set your JCMROOT installation directory
addpath(fullfile(jcm_root, 'ThirdPartySupport', 'Matlab'));

%% shutdown a possibly running daemon
jcmwave_daemon_shutdown();

%% register a new computer resource
jcmwave_daemon_add_workstation('Hostname', 'localhost', ...
			       'Multiplicity', 8, ...
			       'NThreads', 2);

% Define the path to the JCM project
root_dir = fileparts(mfilename('fullpath'));
jcm_path = fullfile(root_dir, 'jcm');
project_file = fullfile(jcm_path, 'project.jcmp');

% Define the parameters
keys = struct( ...
    'h', 55, ...
    'width', 31, ...
    'swa', 88, ...
    'radius', 8, ...
    'derivative_order', 0, ...
    'fem_degree', 3, ...
    'precision', 1e-3, ...
    'n1', 1, ...
    'n2', 1.4, ...
    'n3', 1.967 + 4.443 * 1i, ...
    'theta', 65, ...
    'phi', 45, ...
    'vacuum_wavelength', 365e-9 ...
);

% Convert project_file to a string
project_file_str = char(project_file);

% Calculate the results for a single wavelength
ids = jcmwave_solve(project_file_str, keys, 'temporary', 'yes');
[results, logs] = jcmwave_daemon_wait([ids]);

% Extract and print the ellipsometric angles
Psi_ps = results{1}{3}.Psi_ps{1};
Delta_ps = results{1}{3}.Delta_ps{1};
ThetaIn = results{1}{3}.ThetaIn{1};
PhiIn = results{1}{3}.PhiIn{1};

fprintf('\n\nComputational costs: %d unkowns solved in %g sec with %g GB RAM', ...
results{1}{1}.computational_costs.Unknowns,results{1}{1}.computational_costs.TotalTime, ...
 results{1}{1}.computational_costs.TotalMemory_GB);

fprintf('\nEllipsometric angles: [Psi, Delta] = [%.3f, %.3f] for illumination from [theta, phi] = [%.3f, %.3f]\n', ...
    Psi_ps, Delta_ps, ThetaIn, PhiIn);