import pathlib

import jcmwave

keys = dict(
    # Geometric parameters
    h=55,
    width=31,
    swa=88,
    radius=8,
    # Numerical parameters
    derivative_order=0,
    fem_degree=3,
    precision=1e-3,
    # Material parameters
    n1=1,
    n2=1.4,
    n3=1.967 + 4.443 * 1j,
    # Illumination
    theta=65,
    phi=45,
    vacuum_wavelength=365e-9,
)
# Path to JCM project
jcm_path = pathlib.Path(__file__).parent / "jcm"
project_file = jcm_path / "project.jcmpt"
project_file_str = str(project_file.absolute())

# Calculate the results for a single wavelength
results = jcmwave.solve(project_file_str, keys)

print(
    "\nComputational costs: {:.0f} unkowns solved in {:.0f} sec with {:.3f} GB RAM".format(
        results[0]["computational_costs"]["Unknowns"][0],
        results[0]["computational_costs"]["TotalTime"][0],
        results[0]["computational_costs"]["TotalMemory_GB"][0],
    )
)


print(
    "\n",
    "Ellipsometric angles: [Psi, Delta] = [{:.3f}, {:.3f}] for illumination from [theta, phi] = [{:.3f}, {:.3f}]".format(
        results[2]["Psi_ps"][0][0],
        results[2]["Delta_ps"][0][0],
        results[2]["ThetaIn"][0][0],
        results[2]["PhiIn"][0][0],
    ),
)
